@@ -1,4 +1,4 @@
-# $Id$
+# $Id: phylip.pm,v 1.36.4.3 2006/10/02 23:10:12 sendu Exp $
 #
 # BioPerl module for Bio::AlignIO::phylip
 #
@@ -15,31 +15,31 @@ Bio::AlignIO::phylip - PHYLIP format sequence input/output stream
 
     use Bio::AlignIO;
     use Bio::SimpleAlign;
-	#you can set the name length to something other than the default 10
-	#if you use a version of phylip (hacked) that accepts ids > 10
-    my $phylipstream = new Bio::AlignIO(-format => 'phylip',
-					-fh   => \*STDOUT,
-					-idlength=>30);
+    #you can set the name length to something other than the default 10
+    #if you use a version of phylip (hacked) that accepts ids > 10
+    my $phylipstream = new Bio::AlignIO(-format  => 'phylip',
+                                        -fh      => \*STDOUT,
+                                        -idlength=>30);
     # convert data from one format to another
     my $gcgstream     =  new Bio::AlignIO(-format => 'msf',
-					  -file   => 't/data/cysprot1a.msf');
+                                          -file   => 't/data/cysprot1a.msf');
 
     while( my $aln = $gcgstream->next_aln ) {
-	$phylipstream->write_aln($aln);
+        $phylipstream->write_aln($aln);
     }
 
-    # do it again with phylip sequential format format 
+    # do it again with phylip sequential format format
     $phylipstream->interleaved(0);
     # can also initialize the object like this
     $phylipstream = new Bio::AlignIO(-interleaved => 0,
-				     -format => 'phylip',
-				     -fh   => \*STDOUT,
-				     -idlength=>10);
+                                     -format => 'phylip',
+                                     -fh   => \*STDOUT,
+                                     -idlength=>10);
     $gcgstream     =  new Bio::AlignIO(-format => 'msf',
-				       -file   => 't/data/cysprot1a.msf');    
+                                       -file   => 't/data/cysprot1a.msf');
 
     while( my $aln = $gcgstream->next_aln ) {
-	$phylipstream->write_aln($aln);
+        $phylipstream->write_aln($aln);
     }
 
 =head1 DESCRIPTION
@@ -56,16 +56,15 @@ data in interleaved format.
 =head2 Reporting Bugs
 
 Report bugs to the Bioperl bug tracking system to help us keep track
- the bugs and their resolution.
- Bug reports can be submitted via email or the web:
+the bugs and their resolution. Bug reports can be submitted via the
+web:
 
-  bioperl-bugs@bio.perl.org
-  http://bugzilla.bioperl.org/
+  http://bugzilla.open-bio.org/
 
 =head1 AUTHORS - Heikki Lehvaslaiho and Jason Stajich
 
-Email: heikki@ebi.ac.uk
-Email: jason@bioperl.org
+Email: heikki at ebi.ac.uk
+Email: jason at bioperl.org
 
 =head1 APPENDIX
 
@@ -77,17 +76,18 @@ methods. Internal methods are usually preceded with a _
 # Let the code begin...
 
 package Bio::AlignIO::phylip;
-use vars qw(@ISA $DEFAULTIDLENGTH $DEFAULTLINELEN);
+use vars qw($DEFAULTIDLENGTH $DEFAULTLINELEN $DEFAULTTAGLEN);
 use strict;
 
 use Bio::SimpleAlign;
-use Bio::AlignIO;
+use POSIX; # for the rounding call
 
-@ISA = qw(Bio::AlignIO);
+use base qw(Bio::AlignIO);
 
-BEGIN { 
+BEGIN {
     $DEFAULTIDLENGTH = 10;
     $DEFAULTLINELEN = 60;
+    $DEFAULTTAGLEN = 10;
 }
 
 =head2 new
@@ -100,13 +100,21 @@ BEGIN {
  Function: Initialize a new L<Bio::AlignIO::phylip> reader or writer
  Returns : L<Bio::AlignIO> object
  Args    : [specific for writing of phylip format files]
-           -idlength => integer - length of the id (will pad w/ 
-						    spaces if needed) 
-           -interleaved => boolean - whether or not write as interleaved 
+           -idlength => integer - length of the id (will pad w/
+						    spaces if needed)
+           -interleaved => boolean - whether or not write as interleaved
                                      or sequential format
-           -linelength  => integer of how long a sequence lines should be 
+           -line_length  => integer of how long a sequence lines should be
            -idlinebreak => insert a line break after the sequence id
-                           so that sequence starts on the next line 
+                           so that sequence starts on the next line
+           -flag_SI => whether or not write a "S" or "I" just after
+                       the num.seq. and line len., in the first line
+           -tag_length => integer of how long the tags have to be in
+                         each line between the space separator. set it
+                         to 0 to have 1 tag only.
+           -wrap_sequential => boolean for whether or not sequential
+                                   format should be broken up or a single line
+                                   default is false (single line)
 
 =cut
 
@@ -115,14 +123,21 @@ sub _initialize {
   $self->SUPER::_initialize(@args);
 
   my ($interleave,$linelen,$idlinebreak,
-      $idlength) = $self->_rearrange([qw(INTERLEAVED 
-					 LINELENGTH
-					 IDLINEBREAK
-					 IDLENGTH)],@args);
+      $idlength, $flag_SI, $tag_length,$ws) =
+          $self->_rearrange([qw(INTERLEAVED
+                                LINE_LENGTH
+                                IDLINEBREAK
+                                IDLENGTH
+                                FLAG_SI
+                                TAG_LENGTH
+				WRAP_SEQUENTIAL)],@args);
   $self->interleaved(1) if( $interleave || ! defined $interleave);
   $self->idlength($idlength || $DEFAULTIDLENGTH);
   $self->id_linebreak(1) if( $idlinebreak );
   $self->line_length($linelen) if defined $linelen && $linelen > 0;
+  $self->flag_SI(1) if ( $flag_SI );
+  $self->tag_length($tag_length) if ( $tag_length || $DEFAULTTAGLEN );
+  $self->wrap_sequential($ws ? 1 : 0);
   1;
 }
 
@@ -134,7 +149,7 @@ sub _initialize {
            Throws an exception if trying to read in PHYLIP
            sequential format.
  Returns : L<Bio::SimpleAlign> object
- Args    : 
+ Args    :
 
 =cut
 
@@ -143,60 +158,82 @@ sub next_aln {
     my $entry;
     my ($seqcount, $residuecount, %hash, $name,$str,
 	@names,$seqname,$start,$end,$count,$seq);
-    
+
     my $aln =  Bio::SimpleAlign->new(-source => 'phylip');
-    $entry = $self->_readline and 
+    $entry = $self->_readline and
         ($seqcount, $residuecount) = $entry =~ /\s*(\d+)\s+(\d+)/;
     return 0 unless $seqcount and $residuecount;
-    
+
     # first alignment section
     my $idlen = $self->idlength;
     $count = 0;
-    my $non_interleaved = ! $self->interleaved ;
+    my $iter = 1;
+    my $interleaved = $self->interleaved;
     while( $entry = $self->_readline) {
-	last if( $entry =~ /^\s?$/ && ! $non_interleaved );
+	last if( $entry =~ /^\s?$/ && $interleaved );
 
+	if( $entry =~ /^\s+(\d+)\s+(\d+)\s*$/) {
+	    $self->_pushback($entry);
+	    last;
+	}
 	if( $entry =~ /^\s+(.+)$/ ) {
+	    $interleaved = 0;
 	    $str = $1;
-	    $non_interleaved = 1;
 	    $str =~ s/\s//g;
 	    $count = scalar @names;
 	    $hash{$count} .= $str;
-	} elsif( $entry =~ /^(.{$idlen})\s+(.*)\s$/ ) {
+
+       	} elsif( $entry =~ /^(.{$idlen})\s+(.*)\s$/ ||
+		 $entry =~ /^(.{$idlen})(\S{$idlen}\s+.+)\s$/ # Handle weirdnes s when id is too long
+		 ) {
 	    $name = $1;
 	    $str = $2;
 	    $name =~ s/[\s\/]/_/g;
 	    $name =~ s/_+$//; # remove any trailing _'s
+
 	    push @names, $name;
 	    $str =~ s/\s//g;
 	    $count = scalar @names;
 	    $hash{$count} = $str;
-	} 
-	$self->throw("Not a valid interleaved PHYLIP file!") if $count > $seqcount; 
+	} elsif( $interleaved ) {
+	    if( $entry =~ /^(\S+)\s+(.+)/ ||
+		$entry =~ /^(.{$idlen})(.*)\s$/ ) {
+		$name = $1;
+		$str = $2;
+		$name =~ s/[\s\/]/_/g;
+		$name =~ s/_+$//; # remove any trailing _'s
+		push @names, $name;
+		$str =~ s/\s//g;
+		$count = scalar @names;
+		$hash{$count} = $str;
+	    } else {
+		$self->debug("unmatched line: $entry");
+	    }
+	}
+	$self->throw("Not a valid interleaved PHYLIP file!") if $count > $seqcount;
     }
-    
-    unless( $non_interleaved ) {    
+
+    if( $interleaved ) {
 	# interleaved sections
 	$count = 0;
 	while( $entry = $self->_readline) {
-	    # finish current entry
+            # finish current entry
 	    if($entry =~/\s*\d+\s+\d+/){
 		$self->_pushback($entry);
 		last;
 	    }
 	    $count = 0, next if $entry =~ /^\s$/;
-	    
 	    $entry =~ /\s*(.*)$/ && do {
 		$str = $1;
 		$str =~ s/\s//g;
 		$count++;
 		$hash{$count} .= $str;
 	    };
-	    $self->throw("Not a valid interleaved PHYLIP file!") if $count > $seqcount; 
+	    $self->throw("Not a valid interleaved PHYLIP file! [$count,$seqcount] ($entry)") if $count > $seqcount;
 	}
     }
     return 0 if scalar @names < 1;
-    
+
     # sequence creation
     $count = 0;
     foreach $name ( @names ) {
@@ -213,16 +250,15 @@ sub next_aln {
 	    $end = length($str);
 	}
 	# consistency test
-	$self->throw("Length of sequence [$seqname] is not [$residuecount]! ") 
-	    unless CORE::length($hash{$count}) == $residuecount; 
+	$self->throw("Length of sequence [$seqname] is not [$residuecount] it is ".CORE::length($hash{$count})."! ")
+	    unless CORE::length($hash{$count}) == $residuecount;
 
        $seq = new Bio::LocatableSeq('-seq'=>$hash{$count},
 				    '-id'=>$seqname,
 				    '-start'=>$start,
 				    '-end'=>$end,
-				    );
-
-       $aln->add_seq($seq);
+				   );
+	$aln->add_seq($seq);
 
    }
    return $aln;
@@ -244,75 +280,99 @@ sub write_aln {
     my $count = 0;
     my $wrapped = 0;
     my $maxname;
+    my $width = $self->line_length();
     my ($length,$date,$name,$seq,$miss,$pad,
-	%hash,@arr,$tempcount,$index,$idlength);
-    
+	%hash,@arr,$tempcount,$index,$idlength,$flag_SI,$line_length, $tag_length);
+
     foreach my $aln (@aln) {
-	if( ! $aln || ! $aln->isa('Bio::Align::AlignI')  ) { 
+	if( ! $aln || ! $aln->isa('Bio::Align::AlignI')  ) {
 	    $self->warn("Must provide a Bio::Align::AlignI object when calling write_aln");
 	    next;
 	}
-	$self->throw("All sequences in the alignment must be the same length") 
+	$self->throw("All sequences in the alignment must be the same length")
 	    unless $aln->is_flush(1) ;
 
+        $flag_SI = $self->flag_SI();
 	$aln->set_displayname_flat(); # plain
 	$length  = $aln->length();
-	$self->_print (sprintf(" %s %s\n", $aln->no_sequences, $aln->length));
+        if ($flag_SI) {
+            if ($self->interleaved() ) {
+                $self->_print (sprintf(" %s %s I\n", $aln->no_sequences, $aln->length));
+            } else {
+                $self->_print (sprintf(" %s %s S\n", $aln->no_sequences, $aln->length));
+            }
+        } else {
+            $self->_print (sprintf(" %s %s\n", $aln->no_sequences, $aln->length));
+        }
 
-	$idlength = $self->idlength();	
+	$idlength = $self->idlength();
+	$line_length = $self->line_length();
+	$tag_length = $self->tag_length();
 	foreach $seq ( $aln->each_seq() ) {
 	    $name = $aln->displayname($seq->get_nse);
 	    $name = substr($name, 0, $idlength) if length($name) > $idlength;
-	    $name = sprintf("%-".$idlength."s",$name);	    
+	    $name = sprintf("%-".$idlength."s",$name);
 	    if( $self->interleaved() ) {
 		$name .= '   ' ;
-	    } elsif( $self->id_linebreak) { 
-		$name .= "\n"; 
+	    } elsif( $self->id_linebreak) {
+		$name .= "\n";
 	    }
 
-      #phylip needs dashes not dots 
-      my $seq = $seq->seq();
-      $seq=~s/\./-/g;
+	    #phylip needs dashes not dots
+	    my $seq = $seq->seq();
+	    $seq =~ s/\./-/g;
 	    $hash{$name} = $seq;
 	    push(@arr,$name);
 	}
 
 	if( $self->interleaved() ) {
-	    while( $count < $length ) {	
-		
+            my $numtags;
+            if ($tag_length <= $line_length) {
+                $numtags = floor($line_length/$tag_length);
+                $line_length = $tag_length*$numtags;
+            } else {
+                $numtags = 1;
+            }
+	    while( $count < $length ) {
+
 		# there is another block to go!
 		foreach $name ( @arr ) {
 		    my $dispname = $name;
 		    $dispname = '' if $wrapped;
 		    $self->_print (sprintf("%".($idlength+3)."s",$dispname));
 		    $tempcount = $count;
-		    $index = 0;
-		    while( ($tempcount + $idlength < $length) && ($index < 5)  ) {
+                    $index = 0;
+                    $self->debug("residue count: $count\n") if ($count%100000 == 0);
+		    while( ($tempcount + $tag_length < $length) &&
+			   ($index < $numtags)  ) {
 			$self->_print (sprintf("%s ",substr($hash{$name},
 							    $tempcount,
-							    $idlength)));
-			$tempcount += $idlength;
+							    $tag_length)));
+			$tempcount += $tag_length;
 			$index++;
 		    }
 		    # last
-		    if( $index < 5) {
+		    if( $index < $numtags) {
 			# space to print!
 			$self->_print (sprintf("%s ",substr($hash{$name},
 							    $tempcount)));
-			$tempcount += $idlength;
+			$tempcount += $tag_length;
 		    }
 		    $self->_print ("\n");
 		}
 		$self->_print ("\n");
 		$count = $tempcount;
 		$wrapped = 1;
-	    } 			
+	    }
 	} else {
 	    foreach $name ( @arr ) {
 		my $dispname = $name;
-		$dispname = '' if $wrapped;
-		$self->_print (sprintf("%s%s\n",$dispname,$hash{$name}));
-	    }	
+		my $line = sprintf("%s%s\n",$dispname,$hash{$name});
+		if( $self->wrap_sequential ) {
+		    $line =~ s/(.{1,$width})/$1\n/g;
+		}
+		$self->_print ($line);
+	    }
 	}
     }
     $self->flush if $self->_flush_on_write && defined $self->_fh;
@@ -333,19 +393,41 @@ sub write_aln {
 sub interleaved{
    my ($self,$value) = @_;
    my $previous = $self->{'_interleaved'};
-   if( defined $value ) { 
+   if( defined $value ) {
        $self->{'_interleaved'} = $value;
    }
    return $previous;
 }
 
+=head2 flag_SI
+
+ Title   : flag_SI
+ Usage   : my $flag = $obj->flag_SI
+ Function: Get/Set if the Sequential/Interleaved flag has to be shown
+           after the number of sequences and sequence length
+ Example :
+ Returns : boolean
+ Args    : boolean
+
+
+=cut
+
+sub flag_SI{
+   my ($self,$value) = @_;
+   my $previous = $self->{'_flag_SI'};
+   if( defined $value ) {
+       $self->{'_flag_SI'} = $value;
+   }
+   return $previous;
+}
+
 =head2 idlength
 
  Title   : idlength
- Usage   : my $idlength = $obj->interleaved
- Function: Get/Set value of id length 
- Returns : string 
- Args    : string 
+ Usage   : my $idlength = $obj->idlength
+ Function: Get/Set value of id length
+ Returns : string
+ Args    : string
 
 
 =cut
@@ -362,7 +444,7 @@ sub idlength {
 
  Title   : line_length
  Usage   : $obj->line_length($newval)
- Function: 
+ Function:
  Returns : value of line_length
  Args    : newvalue (optional)
 
@@ -372,17 +454,38 @@ sub idlength {
 sub line_length{
    my ($self,$value) = @_;
    if( defined $value) {
-      $self->{'line_length'} = $value;
+      $self->{'_line_length'} = $value;
     }
-    return $self->{'line_length'} || $DEFAULTLINELEN;
+    return $self->{'_line_length'} || $DEFAULTLINELEN;
 
 }
 
+=head2 tag_length
+
+ Title   : tag_length
+ Usage   : $obj->tag_length($newval)
+ Function:
+ Example : my $tag_length = $obj->tag_length
+ Returns : value of the length for each space-separated tag in a line
+ Args    : newvalue (optional) - set to zero to have one tag per line
+
+
+=cut
+
+sub tag_length{
+   my ($self,$value) = @_;
+   if( defined $value) {
+      $self->{'_tag_length'} = $value;
+    }
+    return $self->{'_tag_length'} || $DEFAULTTAGLEN;
+}
+
+
 =head2 id_linebreak
 
  Title   : id_linebreak
  Usage   : $obj->id_linebreak($newval)
- Function: 
+ Function:
  Returns : value of id_linebreak
  Args    : newvalue (optional)
 
@@ -397,4 +500,24 @@ sub id_linebreak{
     return $self->{'_id_linebreak'} || 0;
 }
 
+
+=head2 wrap_sequential
+
+ Title   : wrap_sequential
+ Usage   : $obj->wrap_sequential($newval)
+ Function:
+ Returns : value of wrap_sequential
+ Args    : newvalue (optional)
+
+
+=cut
+
+sub wrap_sequential{
+   my ($self,$value) = @_;
+   if( defined $value) {
+      $self->{'_wrap_sequential'} = $value;
+    }
+    return $self->{'_wrap_sequential'} || 0;
+}
+
 1;
