@@ -1,4 +1,4 @@
-# $Id$
+# $Id: MedlineBook.pm,v 1.10.4.3 2006/10/02 23:10:12 sendu Exp $
 #
 # BioPerl module for Bio::Biblio::MedlineBook
 #
@@ -15,9 +15,9 @@ Bio::Biblio::MedlineBook - Representation of a MEDLINE book
 
     $obj = new Bio::Biblio::MedlineBook
                   (-editor => new Bio::Biblio::Person
-		                     (-lastname => 'Loukides'),
-		   -isbn  => '0-596-00068-5');
- --- OR ---
+                             (-lastname => 'Loukides'),
+                   -isbn  => '0-596-00068-5');
+  #--- OR ---
 
     $obj = new Bio::Biblio::MedlineBook;
     $obj->isbn ('0-596-00068-5');
@@ -26,7 +26,7 @@ Bio::Biblio::MedlineBook - Representation of a MEDLINE book
 
 A storage object for a MEDLINE book.
 See its place in the class hierarchy in
-http://industry.ebi.ac.uk/openBQS/images/bibobjects_perl.gif
+http://www.ebi.ac.uk/~senger/openbqs/images/bibobjects_perl.gif
 
 =head2 Attributes
 
@@ -36,15 +36,15 @@ The main raison d'etre of this class is to be associated with MEDLINE book artic
 
 =head1 SEE ALSO
 
-=over
+=over 4
 
 =item *
 
-OpenBQS home page: http://industry.ebi.ac.uk/openBQS
+OpenBQS home page: http://www.ebi.ac.uk/~senger/openbqs/
 
 =item *
 
-Comments to the Perl client: http://industry.ebi.ac.uk/openBQS/Client_perl.html
+Comments to the Perl client: http://www.ebi.ac.uk/~senger/openbqs/Client_perl.html
 
 =back
 
@@ -56,21 +56,20 @@ User feedback is an integral part of the evolution of this and other
 Bioperl modules. Send your comments and suggestions preferably to
 the Bioperl mailing list.  Your participation is much appreciated.
 
-  bioperl-l@bioperl.org              - General discussion
-  http://bioperl.org/MailList.shtml  - About the mailing lists
+  bioperl-l@bioperl.org                  - General discussion
+  http://bioperl.org/wiki/Mailing_lists  - About the mailing lists
 
 =head2 Reporting Bugs
 
 Report bugs to the Bioperl bug tracking system to help us keep track
-of the bugs and their resolution. Bug reports can be submitted via
-email or the web:
+of the bugs and their resolution. Bug reports can be submitted via the
+web:
 
-  bioperl-bugs@bioperl.org
-  http://bugzilla.bioperl.org/
+  http://bugzilla.open-bio.org/
 
 =head1 AUTHORS
 
-Heikki Lehvaslaiho (heikki@ebi.ac.uk),
+Heikki Lehvaslaiho (heikki-at-bioperl-dot-org),
 Martin Senger (senger@ebi.ac.uk)
 
 =head1 COPYRIGHT
@@ -92,11 +91,9 @@ This software is provided "as is" without warranty of any kind.
 
 package Bio::Biblio::MedlineBook;
 use strict;
-use vars qw(@ISA);
 
-use Bio::Biblio::Book;
 
-@ISA = qw(Bio::Biblio::Book);
+use base qw(Bio::Biblio::Book);
 
 #
 # a closure with a list of allowed attribute names (these names
